@@ -2,7 +2,7 @@ package Mojo::Pg::PubSub;
 use Mojo::Base 'Mojo::EventEmitter';
 
 use Mojo::JSON qw(from_json to_json);
-use Scalar::Util 'weaken';
+use Scalar::Util qw(weaken);
 
 has pg                 => undef, weak => 1;
 has reconnect_interval => 1;
@@ -25,6 +25,7 @@ sub db {
 
   $db->once(close => sub { $self->emit(disconnect => delete $self->{db}) });
   $db->listen($_) for keys %{$self->{chans}}, 'mojo.pubsub';
+  delete $self->{reconnecting};
   $self->emit(reconnect => $db);
 
   return $db;
@@ -36,7 +37,7 @@ sub json { ++$_[0]{json}{$_[1]} and return $_[0] }
 
 sub listen {
   my ($self, $name, $cb) = @_;
-  $self->db->listen($name) unless @{$self->{chans}{$name} ||= []};
+  $self->db->listen($name) if !@{$self->{chans}{$name} ||= []} && !$self->{reconnecting};
   push @{$self->{chans}{$name}}, $cb;
   return $cb;
 }
@@ -58,15 +59,21 @@ sub reset {
 
 sub unlisten {
   my ($self, $name, $cb) = @_;
+
   my $chan = $self->{chans}{$name};
-  @$chan = $cb ? grep { $cb ne $_ } @$chan : ();
-  $self->db->unlisten($name) and delete $self->{chans}{$name} unless @$chan;
+  unless (@$chan = $cb ? grep { $cb ne $_ } @$chan : ()) {
+    $self->db->unlisten($name) unless $self->{reconnecting};
+    delete $self->{chans}{$name};
+  }
+
   return $self;
 }
 
 sub _disconnect {
   my $self = shift;
 
+  $self->{reconnecting} = 1;
+
   weaken $self;
   my $r;
   $r = Mojo::IOLoop->recurring(
@@ -100,15 +107,13 @@ Mojo::Pg::PubSub - Publish/Subscribe
 
 =head1 DESCRIPTION
 
-L<Mojo::Pg::PubSub> is a scalable implementation of the publish/subscribe
-pattern used by L<Mojo::Pg>. It is based on PostgreSQL notifications and allows
-many consumers to share the same database connection, to avoid many common
+L<Mojo::Pg::PubSub> is a scalable implementation of the publish/subscribe pattern used by L<Mojo::Pg>. It is based on
+PostgreSQL notifications and allows many consumers to share the same database connection, to avoid many common
 scalability problems.
 
 =head1 EVENTS
 
-L<Mojo::Pg::PubSub> inherits all events from L<Mojo::EventEmitter> and can
-emit the following new ones.
+L<Mojo::Pg::PubSub> inherits all events from L<Mojo::EventEmitter> and can emit the following new ones.
 
 =head2 disconnect
 
@@ -126,8 +131,7 @@ Emitted after the current database connection is lost.
     ...
   });
 
-Emitted after switching to a new database connection for sending and receiving
-notifications.
+Emitted after switching to a new database connection for sending and receiving notifications.
 
 =head1 ATTRIBUTES
 
@@ -138,28 +142,24 @@ L<Mojo::Pg::PubSub> implements the following attributes.
   my $pg  = $pubsub->pg;
   $pubsub = $pubsub->pg(Mojo::Pg->new);
 
-L<Mojo::Pg> object this publish/subscribe container belongs to. Note that this
-attribute is weakened.
+L<Mojo::Pg> object this publish/subscribe container belongs to. Note that this attribute is weakened.
 
 =head2 reconnect_interval
 
   my $interval = $pubsub->reconnect_interval;
   $pubsub      = $pubsub->reconnect_interval(0.1);
 
-Amount of time in seconds to wait to reconnect after disconnecting, defaults to
-C<1>.
+Amount of time in seconds to wait to reconnect after disconnecting, defaults to C<1>.
 
 =head1 METHODS
 
-L<Mojo::Pg::PubSub> inherits all methods from L<Mojo::EventEmitter> and
-implements the following new ones.
+L<Mojo::Pg::PubSub> inherits all methods from L<Mojo::EventEmitter> and implements the following new ones.
 
 =head2 db
 
   my $db = $pubsub->db;
 
-Build and cache or get cached L<Mojo::Pg::Database> connection from L</"pg">.
-Used to reconnect if disconnected.
+Build and cache or get cached L<Mojo::Pg::Database> connection from L</"pg">. Used to reconnect if disconnected.
 
   # Reconnect immediately
   $pubsub->unsubscribe('disconnect')->on(disconnect => sub { shift->db });
@@ -168,8 +168,7 @@ Used to reconnect if disconnected.
 
   $pubsub = $pubsub->json('foo');
 
-Activate automatic JSON encoding and decoding with L<Mojo::JSON/"to_json"> and
-L<Mojo::JSON/"from_json"> for a channel.
+Activate automatic JSON encoding and decoding with L<Mojo::JSON/"to_json"> and L<Mojo::JSON/"from_json"> for a channel.
 
   # Send and receive data structures
   $pubsub->json('foo')->listen(foo => sub {
@@ -182,9 +181,8 @@ L<Mojo::JSON/"from_json"> for a channel.
 
   my $cb = $pubsub->listen(foo => sub {...});
 
-Subscribe to a channel, there is no limit on how many subscribers a channel can
-have. Automatic decoding of JSON text to Perl values can be activated with
-L</"json">.
+Subscribe to a channel, there is no limit on how many subscribers a channel can have. Automatic decoding of JSON text
+to Perl values can be activated with L</"json">.
 
   # Subscribe to the same channel twice
   $pubsub->listen(foo => sub {
@@ -202,8 +200,7 @@ L</"json">.
   my $pubsub = Mojo::Pg::PubSub->new(pg => Mojo::Pg->new);
   my $pubsub = Mojo::Pg::PubSub->new({pg => Mojo::Pg->new});
 
-Construct a new L<Mojo::Pg::PubSub> object and subscribe to the L</"disconnect">
-event with default reconnect logic.
+Construct a new L<Mojo::Pg::PubSub> object and subscribe to the L</"disconnect"> event with default reconnect logic.
 
 =head2 notify
 
@@ -211,16 +208,14 @@ event with default reconnect logic.
   $pubsub = $pubsub->notify(foo => 'I ♥ Mojolicious!');
   $pubsub = $pubsub->notify(foo => {bar => 'baz'});
 
-Notify a channel. Automatic encoding of Perl values to JSON text can be
-activated with L</"json">.
+Notify a channel. Automatic encoding of Perl values to JSON text can be activated with L</"json">.
 
 =head2 reset
 
   $pubsub->reset;
 
-Reset all subscriptions and the database connection. This is usually done after
-a new process has been forked, to prevent the child process from stealing
-notifications meant for the parent process.
+Reset all subscriptions and the database connection. This is usually done after a new process has been forked, to
+prevent the child process from stealing notifications meant for the parent process.
 
 =head2 unlisten
 
